@@ -54,7 +54,7 @@ def get_name():
     return "{}:{}".format(random.choice(NAMES), random.randint(10000, 99999))
 
 
-def setup_p2p_params(network_ver, p2p_port, p2p_accept=True, p2p_udp_accept=True, sub_dir=None):
+def setup_p2p_params(network_ver, p2p_port, p2p_accept=False, p2p_udp_accept=False, sub_dir=None):
     """ setup general connection setting """
     # directory params
     if V.DATA_PATH is not None:
@@ -95,9 +95,17 @@ def setup_tor_connection(proxy_host='127.0.0.1', port=9150, f_raise_error=True):
     sock.close()
 
 
+def setup_server_hostname(hostname: str = None):
+    """
+    hostname displayed for others
+    This is useful when proxy provide different ip address
+    """
+    V.MY_HOST_NAME = hostname
+
+
 async def is_reachable(host, port):
     """check a port is opened, finish in 2s"""
-    future = loop.run_in_executor(
+    future: asyncio.Future = loop.run_in_executor(
         None, socket.getaddrinfo, host, port, socket.AF_UNSPEC, socket.SOCK_STREAM)
     try:
         await asyncio.wait_for(future, 10.0)
@@ -109,7 +117,8 @@ async def is_reachable(host, port):
         except OSError:
             continue
         sock.settimeout(2.0)
-        future = loop.run_in_executor(None, sock.connect_ex, host_port)
+        future: asyncio.Future = loop.run_in_executor(
+            None, sock.connect_ex, host_port)
         await asyncio.wait_for(future, 3.0)
         result = future.result()
         loop.run_in_executor(None, sock.close)
@@ -147,6 +156,7 @@ __all__ = [
     "NAMES",
     "get_version",
     "get_name",
+    "setup_server_hostname",
     "is_reachable",
     "is_unbind_port",
     "setup_tor_connection",
